==> openjdk-lts_10.0.1+10.orig.tar.xz: openjdk-10-10.0.1+10/test/hotspot/jtreg/compiler/jvmci/TestValidateModules.java <==
/*
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/**
 * @test
 * @bug 8186145
 * @requires vm.jvmci
 * @library /test/lib
 * @build TestValidateModules jdk.test.lib.process.*
 * @run main TestValidateModules
 * @summary Ensure java --validate-modules works with --XX:+EnableJVMCI
 */

import jdk.test.lib.process.ProcessTools;

public class TestValidateModules {
    public static void main(String... args) throws Exception {
        ProcessTools.executeTestJava("-XX:+UnlockExperimentalVMOptions",
                                     "-XX:+EnableJVMCI",
                                     "--validate-modules")
                .outputTo(System.out)
                .errorTo(System.out)
                .stdoutShouldContain("java.base")
                .stdoutShouldContain("jdk.internal.vm.ci")
                .shouldHaveExitValue(0);
    }
}

==> openjdk-lts_11.0.26+4.orig.tar.xz: openjdk-11-11.0.26+4/test/hotspot/jtreg/compiler/jvmci/TestValidateModules.java <==
/*
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/**
 * @test
 * @bug 8186145
 * @requires vm.jvmci
 * @library /test/lib
 * @build TestValidateModules jdk.test.lib.process.*
 * @run main TestValidateModules
 * @summary Ensure java --validate-modules works with --XX:+EnableJVMCI
 */

import jdk.test.lib.process.ProcessTools;

public class TestValidateModules {
    public static void main(String... args) throws Exception {
        ProcessTools.executeTestJava("-XX:+UnlockExperimentalVMOptions",
                                     "-XX:+EnableJVMCI",
                                     "--validate-modules",
                                     "--list-modules")
                .outputTo(System.out)
                .errorTo(System.out)
                .stdoutShouldContain("java.base")
                .stdoutShouldContain("jdk.internal.vm.ci")
                .shouldHaveExitValue(0);
    }
}
